# ngy
Create MBTiles from IGN maps

## Installation

pip install ngy

## Usage

Script:

    SYNOPSIS
        locus LAT1 LONG1 LAT2 LONG2 POSITION_NAME

    POSITIONAL ARGUMENTS
        LAT1
            Type: float
        LONG1
            Type: float
        LAT2
            Type: float
        LONG2
            Type: float
        POSITION_NAME
            Type: str